Skip to contents

Configuration of arguments to set up chunks. You can check arguments and options in the documentation of the knitr package at https://yihui.org/knitr/options/#chunk-options

Usage

cd_knit_chunk_opts(
  metadata = rmarkdown::metadata,
  fig.width = NULL,
  fig.height = NULL,
  fig.pos = "h",
  cache = FALSE,
  message = FALSE,
  echo = FALSE,
  tidy = FALSE
)

Arguments

metadata

Pass Rmarkdown arguments from yml header for instance title, twocolumn, or lang.